==> kubernetes-model-admissionregistration-4.13.3-sources.jar: annotations/io/fabric8/kubernetes/api/model/authorization/v1/NonResourceRuleFluentImpl.java <==
package io.fabric8.kubernetes.api.model.authorization.v1;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public class NonResourceRuleFluentImpl<A extends NonResourceRuleFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements NonResourceRuleFluent<A> {

    private List<String> nonResourceURLs = new ArrayList<String>();
    private List<String> verbs = new ArrayList<String>();

    public NonResourceRuleFluentImpl() { 
    }


    public NonResourceRuleFluentImpl(NonResourceRule instance) { 
        this.withNonResourceURLs(instance.getNonResourceURLs()); 
        this.withVerbs(instance.getVerbs()); 
    }


    public A addToNonResourceURLs(int index,String item) {
        if (this.nonResourceURLs == null) {this.nonResourceURLs = new ArrayList<String>();}
        this.nonResourceURLs.add(index, item);
        return (A)this;
    }

    public A setToNonResourceURLs(int index,String item) {
        if (this.nonResourceURLs == null) {this.nonResourceURLs = new ArrayList<String>();}
        this.nonResourceURLs.set(index, item); return (A)this;
    }

    public A addToNonResourceURLs(String... items) {
        if (this.nonResourceURLs == null) {this.nonResourceURLs = new ArrayList<String>();}
        for (String item : items) {this.nonResourceURLs.add(item);} return (A)this;
    }

    public A addAllToNonResourceURLs(Collection<String> items) {
        if (this.nonResourceURLs == null) {this.nonResourceURLs = new ArrayList<String>();}
        for (String item : items) {this.nonResourceURLs.add(item);} return (A)this;
    }

    public A removeFromNonResourceURLs(String... items) {
        for (String item : items) {if (this.nonResourceURLs!= null){ this.nonResourceURLs.remove(item);}} return (A)this;
    }

    public A removeAllFromNonResourceURLs(Collection<String> items) {
        for (String item : items) {if (this.nonResourceURLs!= null){ this.nonResourceURLs.remove(item);}} return (A)this;
    }

    public List<String> getNonResourceURLs() {
        return this.nonResourceURLs;
    }

    public String getNonResourceURL(int index) {
        return this.nonResourceURLs.get(index);
    }

    public String getFirstNonResourceURL() {
        return this.nonResourceURLs.get(0);
    }

    public String getLastNonResourceURL() {
        return this.nonResourceURLs.get(nonResourceURLs.size() - 1);
    }

    public String getMatchingNonResourceURL(io.fabric8.kubernetes.api.builder.Predicate<String> predicate) {
        for (String item: nonResourceURLs) { if(predicate.apply(item)){ return item;} } return null;
    }

    public Boolean hasMatchingNonResourceURL(io.fabric8.kubernetes.api.builder.Predicate<String> predicate) {
        for (String item: nonResourceURLs) { if(predicate.apply(item)){ return true;} } return false;
    }

    public A withNonResourceURLs(List<String> nonResourceURLs) {
        if (this.nonResourceURLs != null) { _visitables.get("nonResourceURLs").removeAll(this.nonResourceURLs);}
        if (nonResourceURLs != null) {this.nonResourceURLs = new ArrayList<String>(); for (String item : nonResourceURLs){this.addToNonResourceURLs(item);}} else { this.nonResourceURLs = null;} return (A) this;
    }

    public A withNonResourceURLs(String... nonResourceURLs) {
        if (this.nonResourceURLs != null) {this.nonResourceURLs.clear();}
        if (nonResourceURLs != null) {for (String item :nonResourceURLs){ this.addToNonResourceURLs(item);}} return (A) this;
    }

    public Boolean hasNonResourceURLs() {
        return nonResourceURLs != null && !nonResourceURLs.isEmpty();
    }

    public A addNewNonResourceURL(String arg1) {
        return (A)addToNonResourceURLs(new String(arg1));
    }

    public A addNewNonResourceURL(StringBuilder arg1) {
        return (A)addToNonResourceURLs(new String(arg1));
    }

    public A addNewNonResourceURL(StringBuffer arg1) {
        return (A)addToNonResourceURLs(new String(arg1));
    }

    public A addToVerbs(int index,String item) {
        if (this.verbs == null) {this.verbs = new ArrayList<String>();}
        this.verbs.add(index, item);
        return (A)this;
    }

    public A setToVerbs(int index,String item) {
        if (this.verbs == null) {this.verbs = new ArrayList<String>();}
        this.verbs.set(index, item); return (A)this;
    }

    public A addToVerbs(String... items) {
        if (this.verbs == null) {this.verbs = new ArrayList<String>();}
        for (String item : items) {this.verbs.add(item);} return (A)this;
    }

    public A addAllToVerbs(Collection<String> items) {
        if (this.verbs == null) {this.verbs = new ArrayList<String>();}
        for (String item : items) {this.verbs.add(item);} return (A)this;
    }

    public A removeFromVerbs(String... items) {
        for (String item : items) {if (this.verbs!= null){ this.verbs.remove(item);}} return (A)this;
    }

    public A removeAllFromVerbs(Collection<String> items) {
        for (String item : items) {if (this.verbs!= null){ this.verbs.remove(item);}} return (A)this;
    }

    public List<String> getVerbs() {
        return this.verbs;
    }

    public String getVerb(int index) {
        return this.verbs.get(index);
    }

    public String getFirstVerb() {
        return this.verbs.get(0);
    }

    public String getLastVerb() {
        return this.verbs.get(verbs.size() - 1);
    }

    public String getMatchingVerb(io.fabric8.kubernetes.api.builder.Predicate<String> predicate) {
        for (String item: verbs) { if(predicate.apply(item)){ return item;} } return null;
    }

    public Boolean hasMatchingVerb(io.fabric8.kubernetes.api.builder.Predicate<String> predicate) {
        for (String item: verbs) { if(predicate.apply(item)){ return true;} } return false;
    }

    public A withVerbs(List<String> verbs) {
        if (this.verbs != null) { _visitables.get("verbs").removeAll(this.verbs);}
        if (verbs != null) {this.verbs = new ArrayList<String>(); for (String item : verbs){this.addToVerbs(item);}} else { this.verbs = null;} return (A) this;
    }

    public A withVerbs(String... verbs) {
        if (this.verbs != null) {this.verbs.clear();}
        if (verbs != null) {for (String item :verbs){ this.addToVerbs(item);}} return (A) this;
    }

    public Boolean hasVerbs() {
        return verbs != null && !verbs.isEmpty();
    }

    public A addNewVerb(String arg1) {
        return (A)addToVerbs(new String(arg1));
    }

    public A addNewVerb(StringBuilder arg1) {
        return (A)addToVerbs(new String(arg1));
    }

    public A addNewVerb(StringBuffer arg1) {
        return (A)addToVerbs(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        NonResourceRuleFluentImpl that = (NonResourceRuleFluentImpl) o;
        if (nonResourceURLs != null ? !nonResourceURLs.equals(that.nonResourceURLs) :that.nonResourceURLs != null) return false;
        if (verbs != null ? !verbs.equals(that.verbs) :that.verbs != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(nonResourceURLs,  verbs,  super.hashCode());
    }

}

==> kubernetes-model-admissionregistration-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/authorization/v1/NonResourceRuleFluentImpl.java <==
package io.fabric8.kubernetes.api.model.authorization.v1;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public class NonResourceRuleFluentImpl<A extends NonResourceRuleFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements NonResourceRuleFluent<A> {

    private List<String> nonResourceURLs = new ArrayList<String>();
    private List<String> verbs = new ArrayList<String>();

    public NonResourceRuleFluentImpl() {
    }

    public NonResourceRuleFluentImpl(NonResourceRule instance) {
        this.withNonResourceURLs(instance.getNonResourceURLs()); 
        this.withVerbs(instance.getVerbs()); 
    }

    public A addToNonResourceURLs(int index,String item) {
        if (this.nonResourceURLs == null) {this.nonResourceURLs = new ArrayList<String>();}
        this.nonResourceURLs.add(index, item);
        return (A)this;
    }

    public A setToNonResourceURLs(int index,String item) {
        if (this.nonResourceURLs == null) {this.nonResourceURLs = new ArrayList<String>();}
        this.nonResourceURLs.set(index, item); return (A)this;
    }

    public A addToNonResourceURLs(String... items) {
        if (this.nonResourceURLs == null) {this.nonResourceURLs = new ArrayList<String>();}
        for (String item : items) {this.nonResourceURLs.add(item);} return (A)this;
    }

    public A addAllToNonResourceURLs(Collection<String> items) {
        if (this.nonResourceURLs == null) {this.nonResourceURLs = new ArrayList<String>();}
        for (String item : items) {this.nonResourceURLs.add(item);} return (A)this;
    }

    public A removeFromNonResourceURLs(String... items) {
        for (String item : items) {if (this.nonResourceURLs!= null){ this.nonResourceURLs.remove(item);}} return (A)this;
    }

    public A removeAllFromNonResourceURLs(Collection<String> items) {
        for (String item : items) {if (this.nonResourceURLs!= null){ this.nonResourceURLs.remove(item);}} return (A)this;
    }

    public List<String> getNonResourceURLs() {
        return this.nonResourceURLs;
    }

    public String getNonResourceURL(int index) {
        return this.nonResourceURLs.get(index);
    }

    public String getFirstNonResourceURL() {
        return this.nonResourceURLs.get(0);
    }

    public String getLastNonResourceURL() {
        return this.nonResourceURLs.get(nonResourceURLs.size() - 1);
    }

    public String getMatchingNonResourceURL(Predicate<String> predicate) {
        for (String item: nonResourceURLs) { if(predicate.test(item)){ return item;} } return null;
    }

    public Boolean hasMatchingNonResourceURL(Predicate<String> predicate) {
        for (String item: nonResourceURLs) { if(predicate.test(item)){ return true;} } return false;
    }

    public A withNonResourceURLs(List<String> nonResourceURLs) {
        if (this.nonResourceURLs != null) { _visitables.get("nonResourceURLs").removeAll(this.nonResourceURLs);}
        if (nonResourceURLs != null) {this.nonResourceURLs = new ArrayList<String>(); for (String item : nonResourceURLs){this.addToNonResourceURLs(item);}} else { this.nonResourceURLs = null;} return (A) this;
    }

    public A withNonResourceURLs(String... nonResourceURLs) {
        if (this.nonResourceURLs != null) {this.nonResourceURLs.clear();}
        if (nonResourceURLs != null) {for (String item :nonResourceURLs){ this.addToNonResourceURLs(item);}} return (A) this;
    }

    public Boolean hasNonResourceURLs() {
        return nonResourceURLs != null && !nonResourceURLs.isEmpty();
    }

    public A addNewNonResourceURL(StringBuilder arg1) {
        return (A)addToNonResourceURLs(new String(arg1));
    }

    public A addNewNonResourceURL(int[] arg1,int arg2,int arg3) {
        return (A)addToNonResourceURLs(new String(arg1, arg2, arg3));
    }

    public A addNewNonResourceURL(char[] arg1) {
        return (A)addToNonResourceURLs(new String(arg1));
    }

    public A addNewNonResourceURL(StringBuffer arg1) {
        return (A)addToNonResourceURLs(new String(arg1));
    }

    public A addNewNonResourceURL(byte[] arg1,int arg2) {
        return (A)addToNonResourceURLs(new String(arg1, arg2));
    }

    public A addNewNonResourceURL(byte[] arg1) {
        return (A)addToNonResourceURLs(new String(arg1));
    }

    public A addNewNonResourceURL(char[] arg1,int arg2,int arg3) {
        return (A)addToNonResourceURLs(new String(arg1, arg2, arg3));
    }

    public A addNewNonResourceURL(byte[] arg1,int arg2,int arg3) {
        return (A)addToNonResourceURLs(new String(arg1, arg2, arg3));
    }

    public A addNewNonResourceURL(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)addToNonResourceURLs(new String(arg1, arg2, arg3, arg4));
    }

    public A addNewNonResourceURL(String arg1) {
        return (A)addToNonResourceURLs(new String(arg1));
    }

    public A addToVerbs(int index,String item) {
        if (this.verbs == null) {this.verbs = new ArrayList<String>();}
        this.verbs.add(index, item);
        return (A)this;
    }

    public A setToVerbs(int index,String item) {
        if (this.verbs == null) {this.verbs = new ArrayList<String>();}
        this.verbs.set(index, item); return (A)this;
    }

    public A addToVerbs(String... items) {
        if (this.verbs == null) {this.verbs = new ArrayList<String>();}
        for (String item : items) {this.verbs.add(item);} return (A)this;
    }

    public A addAllToVerbs(Collection<String> items) {
        if (this.verbs == null) {this.verbs = new ArrayList<String>();}
        for (String item : items) {this.verbs.add(item);} return (A)this;
    }

    public A removeFromVerbs(String... items) {
        for (String item : items) {if (this.verbs!= null){ this.verbs.remove(item);}} return (A)this;
    }

    public A removeAllFromVerbs(Collection<String> items) {
        for (String item : items) {if (this.verbs!= null){ this.verbs.remove(item);}} return (A)this;
    }

    public List<String> getVerbs() {
        return this.verbs;
    }

    public String getVerb(int index) {
        return this.verbs.get(index);
    }

    public String getFirstVerb() {
        return this.verbs.get(0);
    }

    public String getLastVerb() {
        return this.verbs.get(verbs.size() - 1);
    }

    public String getMatchingVerb(Predicate<String> predicate) {
        for (String item: verbs) { if(predicate.test(item)){ return item;} } return null;
    }

    public Boolean hasMatchingVerb(Predicate<String> predicate) {
        for (String item: verbs) { if(predicate.test(item)){ return true;} } return false;
    }

    public A withVerbs(List<String> verbs) {
        if (this.verbs != null) { _visitables.get("verbs").removeAll(this.verbs);}
        if (verbs != null) {this.verbs = new ArrayList<String>(); for (String item : verbs){this.addToVerbs(item);}} else { this.verbs = null;} return (A) this;
    }

    public A withVerbs(String... verbs) {
        if (this.verbs != null) {this.verbs.clear();}
        if (verbs != null) {for (String item :verbs){ this.addToVerbs(item);}} return (A) this;
    }

    public Boolean hasVerbs() {
        return verbs != null && !verbs.isEmpty();
    }

    public A addNewVerb(StringBuilder arg1) {
        return (A)addToVerbs(new String(arg1));
    }

    public A addNewVerb(int[] arg1,int arg2,int arg3) {
        return (A)addToVerbs(new String(arg1, arg2, arg3));
    }

    public A addNewVerb(char[] arg1) {
        return (A)addToVerbs(new String(arg1));
    }

    public A addNewVerb(StringBuffer arg1) {
        return (A)addToVerbs(new String(arg1));
    }

    public A addNewVerb(byte[] arg1,int arg2) {
        return (A)addToVerbs(new String(arg1, arg2));
    }

    public A addNewVerb(byte[] arg1) {
        return (A)addToVerbs(new String(arg1));
    }

    public A addNewVerb(char[] arg1,int arg2,int arg3) {
        return (A)addToVerbs(new String(arg1, arg2, arg3));
    }

    public A addNewVerb(byte[] arg1,int arg2,int arg3) {
        return (A)addToVerbs(new String(arg1, arg2, arg3));
    }

    public A addNewVerb(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)addToVerbs(new String(arg1, arg2, arg3, arg4));
    }

    public A addNewVerb(String arg1) {
        return (A)addToVerbs(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        NonResourceRuleFluentImpl that = (NonResourceRuleFluentImpl) o;
        if (nonResourceURLs != null ? !nonResourceURLs.equals(that.nonResourceURLs) :that.nonResourceURLs != null) return false;
        if (verbs != null ? !verbs.equals(that.verbs) :that.verbs != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(nonResourceURLs,  verbs,  super.hashCode());
    }

}
